this.name        = "telescopeeq";
this.author      = "Norby, cag";
this.copyright   = "2013 Norbert Nagy";
this.licence     = "CC BY-NC-SA 4.0";
this.description = "Commands and settings, press mode to cycle, activate to accept or change.";
this.version     = "2.0";

(function(){
"use strict";

this.$eq_Menu = [ 
	[ "Nearest target" ],
	[ "Rescan" ],
	[ "Step forward in the target list" ],
	[ "Step back in the target list" ],
	[ "Steering:", "off", "nearest target only", "both nearest and step in the list"], 
    // cutoff for RemoveInFlight; string 'Steering:' is hard coded in mode()
	// [ "Lightballs:", "off", "navigation only", "ships", "masslock rings", "bright masslock rings", "large" ],
	[ "Lightballs:", "off", "navigation only", "include ships", "large" ],
	[ "Masslock rings:", "current alert/weapons state: off", "current alert/weapons state: on", "brighter" ],
	[ "Sniper ring km:", "off", "5-25.6", "10-25.6", "15-25.6", "5-30", "10-30", "15-30"], //off=10-10
	[ "Targets:", "20 and limitation in red alert", 50, 100, 200 ],
	[ "Visual target:", "off", "weapons off", "no ring", "no station", "no question mark", "all" ],
	[ "Visual target size:", 1, 2, 3, 4, 5, 6, 7, 8 ] 
];
this.$eq_MenuItem = 0; //current item in the commands or settings menu

//equipment events
this.activated = function activated() {
	var that = activated;
	var ws = (that.ws = that.ws || worldScripts.telescope);
	var menu = (that.menu = that.menu || this.$eq_Menu);
	var eq_GetSubItem = (that.eq_GetSubItem = that.eq_GetSubItem || this.$eq_GetSubItem);
	var fmtMasslockMsg = (that.fmtMasslockMsg = that.fmtMasslockMsg || this.$fmtMasslockMsg);

	var item = this.$eq_MenuItem;
	if( item < 4 ) { 												//commands
		switch( item ) {
			case 0: 												//Nearest target
				ws._nearest_Sighting(); 							//lock the nearest target
				break;
			case 1: 												//Rescan
                ws._auto_updates( true );
				break;
			case 2: 												//Step forward in the target list
                ws._chg_curr_Sighting( 1 );
				break;
			case 3: 												//Step back in the target list
                ws._chg_curr_Sighting( -1 );
				break;
		}
	} else { 														//settings
		var submenu = menu[ item ];
		var subitem = eq_GetSubItem( item ) + 1; 				    //step to the next subitem in the current settings
		if( subitem >= submenu.length ) subitem = 1; 				//back to the first subitem (0. is the menuitem)
		switch( item ) {
			case 4: 												//Steering
				ws.$TelescopeMenuSteering = subitem;
				ws._SetSteering( subitem );
				break;
			case 5: 												//Lightballs
				ws.$TelescopeMenuLightballs = subitem;
				ws._SetLightballs( subitem );
				break;
			case 6: 												//MasslockRings
				ws.$TelescopeMenuMasslockRings = subitem;
				ws._SetMasslockRings( subitem );
				break;
			case 7: 												//Sniper ring km
				ws.$TelescopeMenuSniper = subitem;
				ws._SetSniper( subitem );
				break;
			case 8: 												//Targets
				ws.$TelescopeMenuTargets = subitem;
				ws._SetTargets( subitem );
				break;
			case 9: 												//Visual target
				ws.$TelescopeMenuVisual = subitem;
				ws._SetVisual( subitem );
				ws._clear_HUD_Effects();
				if( ws.$FixedTel === 0 )
					ws._showVShip(); 							    //repaint visual target and ring
				else 
                    player.consoleMessage("Your cheaply fixed Telescope can not show visual target, buy full repair.", ws.$ConsoleMsgDurn);
				break;
			case 10: 												//Visual target size
				ws.$TelescopeMenuVisualSize = subitem;
				if( ws.$TelescopeMenuVisual < 2 ) {
					ws.$TelescopeMenuVisual = 2; 					//must at least wp off
					ws._SetVisual( 2 );
				}
				ws._SetVisualSize( subitem );
				ws._clear_HUD_Effects();
				if( ws.$FixedTel === 0 )
					ws._showVShip(); 							    //repaint visual target and ring
				else 
                    player.consoleMessage("Your cheaply fixed Telescope can not show visual target, buy full repair.", ws.$ConsoleMsgDurn);
				break;
		}
		//show subitem in settings
		// player.consoleMessage( menu[ item ][ 0 ] + " " + menu[ item ][ subitem ], ws.$ConsoleMsgDurn );
		let menuStr = menu[ item ][ 0 ],
			subitemStr = menu[ item ][ subitem ];
		if( item === 6 ) {
			subitemStr = fmtMasslockMsg( subitemStr );
		}
		player.consoleMessage( menuStr + " " + subitemStr, ws.$ConsoleMsgDurn );
	}
}

this.$fmtMasslockMsg = function fmtMasslockMsg( msg ) {
	var that = fmtMasslockMsg;
	var ws = (that.ws = that.ws || worldScripts.telescope);

	var [ alert, weapons ]  = ws._getShowStateText();
	return msg.replace( 'current', alert ).replace( 'state', weapons );
}

this.mode = function mode() {
	var that = mode;
	var ws = (that.ws = that.ws || worldScripts.telescope);
	var menu = (that.menu = that.menu || this.$eq_Menu);
	var cutoff = (that.cutoff = that.cutoff || null);
	var eq_GetSubItem = (that.eq_GetSubItem = that.eq_GetSubItem || this.$eq_GetSubItem);
	var fmtMasslockMsg = (that.fmtMasslockMsg = that.fmtMasslockMsg || this.$fmtMasslockMsg);
    
    if( cutoff === null ) {                                         // 1st invocation
        for( let i = 0, len = menu.length; i < len; i++ ) {
            if( menu[ i ][ 0 ] === 'Steering:' ) {
                cutoff = that.cutoff = i;
                break;
            }
        }
    }
    var item = this.$eq_MenuItem + 1;							    //step forward in the current menu
    if( item >= menu.length || (item > cutoff && ws.$RemoveInFlight) ) 
        item = 0;                      	                            //back to the first menu item
    this.$eq_MenuItem = item;
	if( item < 4 ) {												//no subitem with commands
		player.consoleMessage( menu[ item ][ 0 ], ws.$ConsoleMsgDurn );
		if( item < 2 || item > 3 ) {								// not stepping through sightings
			ws._resetIdentDelay();
		}
	} else {
		ws._resetIdentDelay();
		let menuStr = menu[ item ][ 0 ],
			subitemStr = menu[ item ][ eq_GetSubItem( item ) ];
		if( item === 6 ) {
			subitemStr = fmtMasslockMsg( subitemStr );
		}
		player.consoleMessage( menuStr + ' ' + subitemStr, ws.$ConsoleMsgDurn );		
	}
}

//Telescope primable equipment method
this.$eq_GetSubItem = function eq_GetSubItem( item ) {
	var that = eq_GetSubItem;
	var ws = (that.ws = that.ws || worldScripts.telescope);

	var m = null;
	switch( item ) {
		case 4:  													//Steering
			m = ws.$TelescopeMenuSteering;
			if( m > 0 ) return( m );
			return( ws.$Steering + 1 );
		case 5: 													//Lightballs
			m = ws.$TelescopeMenuLightballs;
			if( m > 0 ) return( m );
			if( !ws.$LightBalls ) 			return( 1 ); 			//off ('off')
			if( !ws.$ShipLightBalls ) 		return( 2 ); 			//ship off ('navigation only')
			if( !ws.$LargeLightBalls ) 		return( 3 ); 			//large off ('include ships')
			return( 4 );											//large on ('large')
		case 6: 													//MasslockRings
			let state = ws._getShowState(),							// on/off for current alert/weaps state
				currFlags = ws._currMLFlags();
			let menu = 1;
			if( currFlags & state ) {
				menu = 2;
				if( ws.$BrightMassLockRings ) 
					menu = 3;
			}
			return menu;
		case 7:  													//Sniper ring km
			m = ws.$TelescopeMenuSniper;
			if( m > 0 ) return( m );
			var max = ws.$SniperRange;
			var min = ws.$SniperMinRange;
			if( max === min ) 	return( 1 ); 						//off
			var p = 0; 												//max = 25.6km
			if( max > 25600 ) p = 3; 								//add this to reach subitems with max = 30km
			if( min <= 5000 ) 	return( 2 + p ); 					// "5-25.6" or "5-30"
			if( min >= 15000 )	return( 4 + p ); 					// "15-25.6" or "15-30"
			return( 3 + p ); 										// "10-25.6" or "10-30"
		case 8:  													//Targets
			m = ws.$TelescopeMenuTargets;
			if( m > 0 ) return( m );
			if( ws.$RedAlertLimiter )	return( 1 ); 				//20 and limitation in red alert
			if( ws.$MaxTargets <= 50 )	return( 2 ); 				//50
			if( ws.$MaxTargets >= 200 ) return( 4 ); 				//200
			return( 3 ); 											//100
		case 9:  													//Visual target
			m = ws.$TelescopeMenuVisual;
			if( m > 0 ) return( m );
			if( ws.$VisualTargetNormalSize === 0 
                || ws.$ShowVisualTarget === 0 ) 	return( 1 ); 	//off
			if( ws.$ShowVisualTarget === 1 )	    return( 2 ); 	//weapons off
			if( !ws.$Ring ) 						return( 3 ); 	//no ring
			if( !ws.$ShowVisualStation ) 		 	return( 4 );	//no station
			if( !ws.$ShowVisualQuestionMark )		return( 5 ); 	//no "?"
			return( 6 ); 											//all
		case 10:  													//Visual target size (VZoomSize=0 if full off)
			m = ws.$TelescopeMenuVisualSize;
			if( m > 0 ) return( m );
			return( ws.$VisualTargetNormalSize );
	}
	return( -2 ); 													//no subitem with commands
}

}).call(this);
